#!/bin/bash

DEFAULT_RELEASE=xenial

if [ ! -d debian ]; then
    echo "Seems that you run this script outside of sources directory"
    exit 1
fi

releases="$*"

if [ -z "$releases" ]; then
    if [ -f "../releases" ]; then
        releases=`cat ../releases`
    fi
fi

if [ -z "$releases" ]; then
    if [ -f "debian/releases" ]; then
        releases=`cat debian/releases`
    fi
fi

if [ -z "$releases" ]; then
    releases="$DEFAULT_RELEASE"
fi

echo "Use releases: $releases"

for r in $releases
do
    line=`head -1 debian/changelog`
    tst1=`echo $line | grep '~unstable~'`
    tst11=`echo $line | grep -- '-unstable~'`
    tst12=`echo $line | grep -- '[0-9]unstable[0-9]'`
    tst2=`echo $line | grep ' unstable;'`
    if [ \( -z "$tst1" -a -z "$tst11" -a -z "$tst12" \) -o -z "$tst2" ]; then
        echo "First line does not contain '~unstable~', '-unstable~' or [0-9]unstable[0-9] pattern in revision and/or 'unstalbe' as release:"
        echo "$line"
        exit 1
    fi

    cp debian/changelog debian/changelog.tmp
    sed -i "0,/RE/s/\([~-]\)unstable~/\1$r~/g" debian/changelog
    sed -i "0,/RE/s/\([0-9]\)unstable\([0-9]\)/\1$r\2/g" debian/changelog
    sed -i "0,/RE/s/ unstable;/ $r;/"  debian/changelog

    # prepare release-specific files
    find debian -name "*.$r" -print | while read line
    do
        dir=`dirname $line`
        name=`basename $line .$r`
        path="$dir/$name"
        cp "$line" "$path"
    done

    dpkg-buildpackage -d -S

    mv debian/changelog.tmp debian/changelog
done
